@@ -213,7 +213,13 @@ class nqdm(tqdm.tqdm):
         y = [fn(type(y_i))*1 for fn in functions]
 
         # No overlapping allowed due to the simplicity reasons
+        # If possible try to convert to list
         if sum(y) != 1:
+            try:
+                if hasattr(y_i, "__len__") or hasattr(y_i, "__iter__"):
+                    y_i = list(y_i)
+            except:
+                pass
             return y_i, type(y_i)
 
         # Convert to list
@@ -432,4 +438,4 @@ class nqdm(tqdm.tqdm):
         # reduce dimension if just one element
         elems = informations[0] if len(informations) == 1 else self.__oldorder__(informations)
 
-        return elems
+        return elems
\ No newline at end of file
